/***********************************************************************************
Note to User: The purpose of this program is to provide sample SAS code for running
weighted frequencies and means for the FMLA 2018 Employee Survey, as well as for testing
for differences across subgroups, using employee weights.

Before running this program, please update the file path in the libname statement.
The file path in this statement should refer to the location on your computer where 
both the FMLA 2018 Employee Public Use File dataset (FMLA_2018_Employee_PUF.sas7bdat) 
and the corresponding formats catalog (fmla_2018_employee_formats.sas7bcat) are saved.

Finally, the public use file documentation included examples using a hypothetical 
indicator variable called male that could be created from the existing gender_cat 
variable. By contrast, the examples below include only variables that appear in the 
FMLA 2018 Employee Public Use File dataset.
***********************************************************************************/

libname in "INSERT FILE PATH HERE";

options fmtsearch=(in.fmla_2018_employee_formats);

/*************************************************************************
Run weighted frequencies and means for FMLA 2018 Employee Survey 
*************************************************************************/

/*Run weighted frequencies of FMLA eligibility on full sample*/
PROC SURVEYFREQ DATA=in.FMLA_2018_Employee_PUF VARMETHOD = BRR;
WEIGHT combo_trimmed_weight;
REPWEIGHTS cmb_bsrw1 - cmb_bsrw200;
TABLES fmla_eligible;
RUN; 

/*Run weighted frequencies of FMLA eligibility and worker earnings (whether worker earns less than $15 per hour)*/
PROC SURVEYFREQ DATA=in.FMLA_2018_Employee_PUF VARMETHOD = BRR;
WEIGHT combo_trimmed_weight;
REPWEIGHT cmb_bsrw1 - cmb_bsrw200;
TABLES fmla_eligible * low_wage;
RUN; 

/*Test whether percentage of employees earning less than $15 per hour differs by FMLA eligibility*/
PROC SURVEYREG DATA = in.FMLA_2018_Employee_PUF  VARMETHOD = BRR;
CLASS fmla_eligible;
WEIGHT combo_trimmed_weight;
REPWEIGHTS cmb_bsrw1 - cmb_bsrw200;
MODEL low_wage = fmla_eligible;
LSMEANS fmla_eligible/DIFF;
RUN;
